==> estateplat-common-1.2.4-20200408.011232-310-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxxCxjl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018-5-17
 * @description 不动产收费信息查询记录表
 */
@Table(name = "BDC_SFXXCXJL")
public class BdcSfxxCxjl {
    @Id
    private String jlid; //记录id
    private String cxbh; //查询编号
    private String qlrmc; //权利人名称
    private String jdmc; //节点名称
    private String lcmc; //流程名称
    private Date cjkssj; //创建开始时间
    private Date cjjssj; //创建结束时间
    private String czrmc; //操作人名称
    private Date czsj; //操作时间
    private String czip; //操作IP地址

    public String getJlid() {
        return jlid;
    }

    public void setJlid(String jlid) {
        this.jlid = jlid;
    }

    public String getCxbh() {
        return cxbh;
    }

    public void setCxbh(String cxbh) {
        this.cxbh = cxbh;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getJdmc() {
        return jdmc;
    }

    public void setJdmc(String jdmc) {
        this.jdmc = jdmc;
    }

    public String getLcmc() {
        return lcmc;
    }

    public void setLcmc(String lcmc) {
        this.lcmc = lcmc;
    }

    public Date getCjkssj() {
        return cjkssj;
    }

    public void setCjkssj(Date cjkssj) {
        this.cjkssj = cjkssj;
    }

    public Date getCjjssj() {
        return cjjssj;
    }

    public void setCjjssj(Date cjjssj) {
        this.cjjssj = cjjssj;
    }

    public String getCzrmc() {
        return czrmc;
    }

    public void setCzrmc(String czrmc) {
        this.czrmc = czrmc;
    }

    public Date getCzsj() {
        return czsj;
    }

    public void setCzsj(Date czsj) {
        this.czsj = czsj;
    }

    public String getCzip() {
        return czip;
    }

    public void setCzip(String czip) {
        this.czip = czip;
    }
}

==> estateplat-common-1.2.4-20210419.084116-718-sources.jar: cn/gtmap/estateplat/model/server/core/BdcSfxxCxjl.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018-5-17
 * @description 不动产收费信息查询记录表
 */
@Table(name = "BDC_SFXXCXJL")
public class BdcSfxxCxjl {
    @Id
    private String jlid; //记录id
    private String cxbh; //查询编号
    private String qlrmc; //权利人名称
    private String jdmc; //节点名称
    private String lcmc; //流程名称
    private Date cjkssj; //创建开始时间
    private Date cjjssj; //创建结束时间
    private String czrmc; //操作人名称
    private Date czsj; //操作时间
    private String czip; //操作IP地址
    private String sfykqjf;//是否一卡清缴费

    public String getJlid() {
        return jlid;
    }

    public void setJlid(String jlid) {
        this.jlid = jlid;
    }

    public String getCxbh() {
        return cxbh;
    }

    public void setCxbh(String cxbh) {
        this.cxbh = cxbh;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getJdmc() {
        return jdmc;
    }

    public void setJdmc(String jdmc) {
        this.jdmc = jdmc;
    }

    public String getLcmc() {
        return lcmc;
    }

    public void setLcmc(String lcmc) {
        this.lcmc = lcmc;
    }

    public Date getCjkssj() {
        return cjkssj;
    }

    public void setCjkssj(Date cjkssj) {
        this.cjkssj = cjkssj;
    }

    public Date getCjjssj() {
        return cjjssj;
    }

    public void setCjjssj(Date cjjssj) {
        this.cjjssj = cjjssj;
    }

    public String getCzrmc() {
        return czrmc;
    }

    public void setCzrmc(String czrmc) {
        this.czrmc = czrmc;
    }

    public Date getCzsj() {
        return czsj;
    }

    public void setCzsj(Date czsj) {
        this.czsj = czsj;
    }

    public String getCzip() {
        return czip;
    }

    public void setCzip(String czip) {
        this.czip = czip;
    }

    public String getSfykqjf() {
        return sfykqjf;
    }

    public void setSfykqjf(String sfykqjf) {
        this.sfykqjf = sfykqjf;
    }
}
